@@ -21,7 +21,9 @@
 #include <KAboutData>
 #include <KCrash>
 #include <KDBusService>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
+#endif
 #include <KLocalizedString>
 
 #include <iostream>
@@ -68,11 +70,12 @@ int main(int argc, char **argv)
 
     // Debug output can be turned on here:
     //QLoggingCategory::setFilterRules(QStringLiteral("ark.debug = true"));
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("ark"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("arkrc"));
     migrate.setUiFiles(QStringList() << QStringLiteral("arkuirc"));
     migrate.migrate();
+#endif
 
     KLocalizedString::setApplicationDomain("ark");
 
